---
sidebar_label: frequent_itemsets_hypergraph
title: modules.itemsets.frequent_itemsets_hypergraph
---

## FrequentItemsetsHypergraph Objects

```python
class FrequentItemsetsHypergraph(Experiment)
```

Creates a hypergraph directly from the frequent itemsets resulting
from the patients input

